Struct cpython::PyUnicode [−][src]
pub struct PyUnicode(_);Expand description
Represents a Python string.
Corresponds to basestring in Python 2, and str in Python 3.
Implementations
Creates a new Python string object.
On Python 2.7, this function will create a byte string if the
feature py2-no-auto-unicode-promotion is set, or the input
input string is ASCII-only; otherwise, the input string will be
converted to a unicode string.
Use PyUnicode::new() to always create a unicode string.
On Python 3.x, this function always creates unicode str objects.
Panics if out of memory.
Gets the python string data in its underlying representation.
For Python 2 byte strings, this function always returns PyStringData::Utf8,
even if the bytes are not valid UTF-8.
For unicode strings, returns the underlying representation used by Python.
Convert the PyString into a Rust string.
On Python 2.7, if the PyString refers to a byte string,
it will be decoded using UTF-8.
Returns a UnicodeDecodeError if the input is not valid unicode
(containing unpaired surrogates, or a Python 2.7 byte string that is
not valid UTF-8).
Convert the PyString into a Rust string.
On Python 2.7, if the PyString refers to a byte string,
it will be decoded using UTF-8.
Unpaired surrogates and (on Python 2.7) invalid UTF-8 sequences are replaced with U+FFFD REPLACEMENT CHARACTER.