Struct cpython::GILGuard [−][src]
pub struct GILGuard { /* fields omitted */ }Expand description
RAII type that represents the Global Interpreter Lock acquisition.
Example
use cpython::Python;
{
let gil_guard = Python::acquire_gil();
let py = gil_guard.python();
} // GIL is released when gil_guard is droppedImplementations
Acquires the global interpreter lock, which allows access to the Python runtime.
If the Python runtime is not already initialized, this function will initialize it. See prepare_freethreaded_python() for details.
Retrieves the marker type that proves that the GIL was acquired.