[−][src]Struct cpython::GILProtected
Mutex-like wrapper object for data that is protected by the Python GIL.
Example
use std::cell::Cell; use cpython::{Python, GILProtected}; let data = GILProtected::new(Cell::new(0)); { let gil_guard = Python::acquire_gil(); let cell = data.get(gil_guard.python()); cell.set(cell.get() + 1); }
Methods
impl<T> GILProtected<T>[src]
pub fn new(data: T) -> GILProtected<T>[src]
Creates a new instance of GILProtected.
pub fn get<'a>(&'a self, _py: Python<'a>) -> &'a T[src]
Returns a shared reference to the data stored in the GILProtected.
Requires a Python instance as proof that the GIL is acquired.
pub fn into_inner(self) -> T[src]
Consumes the GILProtected, returning the wrapped value.