Struct cpython::PyType [−][src]
Represents a reference to a Python type object.
Implementations
impl PyType[src]
pub fn as_type_ptr(&self) -> *mut PyTypeObject[src]
Retrieves the underlying FFI pointer associated with this Python object.
pub unsafe fn from_type_ptr(py: Python<'_>, p: *mut PyTypeObject) -> PyType[src]
Retrieves the PyType instance for the given FFI pointer. This increments the reference count on the type object. Undefined behavior if the pointer is NULL or invalid.
pub fn name<'a>(&'a self, _py: Python<'a>) -> Cow<'a, str>[src]
Gets the name of the PyType.
pub fn is_subtype_of(&self, _: Python<'_>, b: &PyType) -> bool[src]
Return true if self is a subtype of b.
pub fn is_instance(&self, _: Python<'_>, obj: &PyObject) -> bool[src]
Return true if obj is an instance of self.
pub fn call<A>(
&self,
py: Python<'_>,
args: A,
kwargs: Option<&PyDict>
) -> PyResult<PyObject> where
A: ToPyObject<ObjectType = PyTuple>, [src]
&self,
py: Python<'_>,
args: A,
kwargs: Option<&PyDict>
) -> PyResult<PyObject> where
A: ToPyObject<ObjectType = PyTuple>,
Calls the type object, thus creating a new instance.
This is equivalent to the Python expression: self(*args, **kwargs)