Struct cpython::PyUnicode [−][src]
pub struct PyUnicode(_);
Represents a Python string.
Corresponds to basestring in Python 2, and str in Python 3.
Methods
impl PyString[src]
impl PyStringpub fn new(py: Python, s: &str) -> PyString[src]
pub fn new(py: Python, s: &str) -> PyStringCreates a new Python string object.
On Python 2.7, this function will create a byte string if the
input string is ASCII-only; and a unicode string otherwise.
Use PyUnicode::new() to always create a unicode string.
Panics if out of memory.
pub fn data(&self, py: Python) -> PyStringData[src]
pub fn data(&self, py: Python) -> PyStringDataGets the python string data in its underlying representation.
For Python 2 byte strings, this function always returns PyStringData::Utf8,
even if the bytes are not valid UTF-8.
For unicode strings, returns the underlying representation used by Python.
pub fn to_string(&self, py: Python) -> PyResult<Cow<str>>[src]
pub fn to_string(&self, py: Python) -> PyResult<Cow<str>>Convert the PyString into a Rust string.
On Python 2.7, if the PyString refers to a byte string,
it will be decoded using UTF-8.
Returns a UnicodeDecodeError if the input is not valid unicode
(containing unpaired surrogates, or a Python 2.7 byte string that is
not valid UTF-8).
pub fn to_string_lossy(&self, py: Python) -> Cow<str>[src]
pub fn to_string_lossy(&self, py: Python) -> Cow<str>Convert the PyString into a Rust string.
On Python 2.7, if the PyString refers to a byte string,
it will be decoded using UTF-8.
Unpaired surrogates and (on Python 2.7) invalid UTF-8 sequences are replaced with U+FFFD REPLACEMENT CHARACTER.