Trait cpython::PythonObjectWithTypeObject [−][src]
pub trait PythonObjectWithTypeObject: PythonObjectWithCheckedDowncast { fn type_object(_: Python) -> PyType; }
Trait implemented by Python object types that have a corresponding type object.
Required Methods
fn type_object(_: Python) -> PyType
Retrieves the type object for this Python object type.
Implementors
impl PythonObjectWithTypeObject for PyObjectimpl PythonObjectWithTypeObject for PyTypeimpl PythonObjectWithTypeObject for PyModuleimpl PythonObjectWithTypeObject for PyStringimpl PythonObjectWithTypeObject for PyBytesimpl PythonObjectWithTypeObject for PyDictimpl PythonObjectWithTypeObject for PyBoolimpl PythonObjectWithTypeObject for PyTupleimpl PythonObjectWithTypeObject for PyListimpl PythonObjectWithTypeObject for PyLongimpl PythonObjectWithTypeObject for PyFloatimpl PythonObjectWithTypeObject for BaseExceptionimpl PythonObjectWithTypeObject for Exceptionimpl PythonObjectWithTypeObject for LookupErrorimpl PythonObjectWithTypeObject for AssertionErrorimpl PythonObjectWithTypeObject for AttributeErrorimpl PythonObjectWithTypeObject for EOFErrorimpl PythonObjectWithTypeObject for EnvironmentErrorimpl PythonObjectWithTypeObject for FloatingPointErrorimpl PythonObjectWithTypeObject for IOErrorimpl PythonObjectWithTypeObject for ImportErrorimpl PythonObjectWithTypeObject for IndexErrorimpl PythonObjectWithTypeObject for KeyErrorimpl PythonObjectWithTypeObject for KeyboardInterruptimpl PythonObjectWithTypeObject for MemoryErrorimpl PythonObjectWithTypeObject for NameErrorimpl PythonObjectWithTypeObject for NotImplementedErrorimpl PythonObjectWithTypeObject for OSErrorimpl PythonObjectWithTypeObject for OverflowErrorimpl PythonObjectWithTypeObject for ReferenceErrorimpl PythonObjectWithTypeObject for RuntimeErrorimpl PythonObjectWithTypeObject for SyntaxErrorimpl PythonObjectWithTypeObject for SystemErrorimpl PythonObjectWithTypeObject for SystemExitimpl PythonObjectWithTypeObject for TypeErrorimpl PythonObjectWithTypeObject for ValueErrorimpl PythonObjectWithTypeObject for ZeroDivisionErrorimpl PythonObjectWithTypeObject for BufferErrorimpl PythonObjectWithTypeObject for UnicodeDecodeErrorimpl PythonObjectWithTypeObject for UnicodeEncodeErrorimpl PythonObjectWithTypeObject for UnicodeTranslateError